@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------
    Copyright 2012 Daniel C. Bünzli. All rights reserved.
    Distributed under the BSD3 license, see license at the end of the file.
-   uutf release 0.9.3
+   uutf release 0.9.4
   ---------------------------------------------------------------------------*)
 
 (** Non-blocking streaming Unicode codec.
@@ -10,7 +10,7 @@
   {{:#encode}encode} the {{:http://www.ietf.org/rfc/rfc3629.txt}
   UTF-8}, {{:http://www.ietf.org/rfc/rfc2781.txt} UTF-16}, UTF-16LE
   and UTF-16BE encoding schemes. It can efficiently work character by
-  character without blocking on IO. Decoders perform 
+  character without blocking on IO. Decoders perform
   character position tracking and support {{!nln}newline normalization}.
 
   Functions are also provided to {{!String} fold over} the
@@ -20,16 +20,16 @@
 
   See {{:#examples}examples} of use.
 
-  {e Release 0.9.3 - Daniel Bünzli <daniel.buenzl i\@erratique.ch> }
+  {e Release 0.9.4 - Daniel Bünzli <daniel.buenzl i\@erratique.ch> }
 
   {3 References}
-    {ul 
-    {- The Unicode Consortium. 
-    {e {{:http://www.unicode.org/versions/latest}The Unicode Standard}}. 
+    {ul
+    {- The Unicode Consortium.
+    {e {{:http://www.unicode.org/versions/latest}The Unicode Standard}}.
     (latest version)}}
 *)
 
-  (** {1:basic Unicode characters} 
+  (** {1:basic Unicode characters}
 
       [Uutf] uses the term character for a Unicode
       {{:http://unicode.org/glossary/#unicode_scalar_value} scalar
@@ -43,17 +43,17 @@
 
 type uchar = int
 (** The type for Unicode characters. Any value of this type returned
-    by [Uutf] is a Unicode 
+    by [Uutf] is a Unicode
     {{:http://unicode.org/glossary/#unicode_scalar_value}
     scalar value}. *)
 
-val u_bom : uchar 
+val u_bom : uchar
 (** [u_bom] is the {{:http://unicode.org/glossary/#byte_order_mark}byte
     order mark} (BOM) character ([U+FEFF]). *)
 
-val u_rep : uchar 
+val u_rep : uchar
 (** [u_rep] is the
-    {{:http://unicode.org/glossary/#replacement_character}replacement} 
+    {{:http://unicode.org/glossary/#replacement_character}replacement}
     character ([U+FFFD]). *)
 
 val is_uchar : int -> bool
@@ -82,8 +82,8 @@ type encoding = [ `UTF_16 | `UTF_16BE | `UTF_16LE | `UTF_8 ]
     schemes}. *)
 
 type decoder_encoding = [ encoding | `US_ASCII | `ISO_8859_1 ]
-(** The type for encoding schemes {e decoded} by [Uutf]. Unicode encoding 
-    schemes plus {{:http://tools.ietf.org/html/rfc20}US-ASCII} and 
+(** The type for encoding schemes {e decoded} by [Uutf]. Unicode encoding
+    schemes plus {{:http://tools.ietf.org/html/rfc20}US-ASCII} and
     {{:http://www.ecma-international.org/publications/standards/Ecma-094.htm}
     ISO/IEC 8859-1} (latin-1). *)
 
@@ -100,11 +100,11 @@ val encoding_to_string : [< decoder_encoding] -> string
 (** {1:decode Decode} *)
 
 type src = [ `Channel of in_channel | `String of string | `Manual ]
-(** The type for input sources. With a [`Manual] source the client 
+(** The type for input sources. With a [`Manual] source the client
     must provide input with {!Manual.src}. *)
 
 type nln = [ `ASCII of uchar | `NLF of uchar | `Readline of uchar ]
-(** The type for newline normalizations. The variant argument is the 
+(** The type for newline normalizations. The variant argument is the
     normalization character.
     {ul
     {- [`ASCII], normalizes CR ([U+000D]), LF ([U+000A]) and CRLF
@@ -112,17 +112,17 @@ type nln = [ `ASCII of uchar | `NLF of uchar | `Readline of uchar ]
     {- [`NLF], normalizes the Unicode newline function (NLF). This is
        NEL ([U+0085]) and the normalizations of [`ASCII].}
     {- [`Readline], normalizes for a Unicode readline function. This is FF
-       ([U+000C]), LS ([U+2028]), PS ([U+2029]), and the normalizations 
+       ([U+000C]), LS ([U+2028]), PS ([U+2029]), and the normalizations
        of [`NLF].}}
-    Used with an appropriate normalization character the [`NLF] and 
-    [`Readline] normalizations allow to implement all the different 
-    recommendations of Unicode's newline guidelines (section 5.8 in 
+    Used with an appropriate normalization character the [`NLF] and
+    [`Readline] normalizations allow to implement all the different
+    recommendations of Unicode's newline guidelines (section 5.8 in
     Unicode 6.1.0). *)
 
 type decoder
 (** The type for decoders. *)
 
-val decoder : ?nln:[< nln] -> ?encoding:[< decoder_encoding] -> [< src] -> 
+val decoder : ?nln:[< nln] -> ?encoding:[< decoder_encoding] -> [< src] ->
   decoder
 (** [decoder nln encoding src] is a decoder that inputs from [src].
 
@@ -158,7 +158,7 @@ val decoder : ?nln:[< nln] -> ?encoding:[< decoder_encoding] -> [< src] ->
 {[
 xx = any byte
 .. = any byte or no byte (input too small)
-pp = positive byte 
+pp = positive byte
 uu = valid UTF-8 first byte
 
 Bytes    | Guess     | Rationale
@@ -170,7 +170,7 @@ FF FE .. | `UTF_16LE | UTF-16LE BOM
 pp 00 .. | `UTF_16LE | ASCII UTF-16LE and U+0000 is often forbidden
 uu .. .. | `UTF_8    | ASCII UTF-8 or valid UTF-8 first byte.
 xx xx .. | `UTF_16BE | Not UTF-8 => UTF-16, no BOM => UTF-16BE
-.. .. .. | `UTF_8    | Single malformed UTF-8 byte or no input. 
+.. .. .. | `UTF_8    | Single malformed UTF-8 byte or no input.
 ]}
     This heuristic is compatible both with BOM based
     recognitition and
@@ -178,7 +178,7 @@ xx xx .. | `UTF_16BE | Not UTF-8 => UTF-16, no BOM => UTF-16BE
     recognition} that relies on ASCII being present at the beginning
     of the stream. Also, {!decoder_removed_bom} will tell the client
     if the guess was BOM based.
-    
+
     {b Newline normalization.} If [nln] is specified, the given
     newline normalization is performed, see {!nln}. Otherwise
     all newlines are returned as found in the input.
@@ -193,8 +193,8 @@ xx xx .. | `UTF_16BE | Not UTF-8 => UTF-16, no BOM => UTF-16BE
     the column set to zero. For example the line is [2] and column [0]
     after the first newline was decoded. This can be understood as if {!decode}
     was moving an insertion point to the right in the data.  A {e
-    newline} is anything normalized by [`Readline], see {!nln}. 
-    
+    newline} is anything normalized by [`Readline], see {!nln}.
+
     [Uutf] assumes that each Unicode scalar value has a column width
     of 1. The same assumption may not be made by the display program
     (e.g. for [emacs]' compilation mode you need to set
@@ -204,40 +204,40 @@ xx xx .. | `UTF_16BE | Not UTF-8 => UTF-16, no BOM => UTF-16BE
     {{:http://unicode.org/reports/tr29/#Grapheme_Cluster_Boundaries}
     grapheme cluster boundaries}. *)
 
-val decode : decoder -> 
+val decode : decoder ->
   [ `Await | `Uchar of uchar | `End | `Malformed of string]
 (** [decode d] is:
     {ul
-    {- [`Await] if [d] has a [`Manual] input source and awaits 
+    {- [`Await] if [d] has a [`Manual] input source and awaits
        for more input. The client must use {!Manual.src} to provide it.}
     {- [`Uchar u] if a Unicode scalar value [u] was decoded.}
     {- [`End] if the end of input was reached.}
-    {- [`Malformed bytes] if the [bytes] sequence is malformed according to 
+    {- [`Malformed bytes] if the [bytes] sequence is malformed according to
        the decoded encoding scheme. If you are interested in a best-effort
        decoding you can still continue to decode after an error until the
        decoder synchronizes again on valid bytes. It may however be a good
        idea to signal the malformed characters by adding an {!u_rep}
-       character to the parsed data, see the {{:#examples}examples}.}} 
+       character to the parsed data, see the {{:#examples}examples}.}}
 
     {b Note.} Repeated invocation always eventually returns [`End], even
     in case of errors.  *)
 
 val decoder_encoding : decoder -> decoder_encoding
-(** [decoder_encoding d] is [d]'s the decoded encoding scheme of [d]. 
+(** [decoder_encoding d] is [d]'s the decoded encoding scheme of [d].
 
-    {b Warning.} If the decoder guesses the encoding or uses [`UTF_16], 
+    {b Warning.} If the decoder guesses the encoding or uses [`UTF_16],
     rely on this value only after the first [`Uchar] was decoded. *)
 
 (**/**)
 
-(* This function is dangerous, it may destroy the current continuation. 
+(* This function is dangerous, it may destroy the current continuation.
    But it's needed for things like XML parsers. *)
 
 val set_decoder_encoding : decoder -> [< decoder_encoding] -> unit
-(** [set_decoder_encoding d enc] changes the decoded encoding 
+(** [set_decoder_encoding d enc] changes the decoded encoding
     to [enc] after decoding started.
-    
-    {b Warning.} Call only after {!decode} was called on [d] and that the 
+
+    {b Warning.} Call only after {!decode} was called on [d] and that the
     last call to it returned something different from [`Await] or data may
     be lost. After encoding guess wait for at least three [`Uchar]s. *)
 
@@ -248,9 +248,14 @@ val decoder_line : decoder -> int
     decoded (or malformed) character. See {!decoder} for details. *)
 
 val decoder_col : decoder -> int
-(** [decoder_col d] is the column number of the last decoded 
+(** [decoder_col d] is the column number of the last decoded
     (or malformed) character. See {!decoder} for details. *)
-    
+
+val decoder_byte_count : decoder -> int
+(** [decoder_byte_count d] is the number of bytes already decoded on
+    [d] (including malformed ones). This is the last {!decode}'s
+    end byte offset counting from the beginning of the stream. *)
+
 val decoder_count : decoder -> int
 (** [decoder_count d] is the number of characters already decoded on [d]
     (including malformed ones). See {!decoder} for details. *)
@@ -266,7 +271,7 @@ val decoder_src : decoder -> src
 val decoder_nln : decoder -> nln option
 (** [decoder_nln d] returns [d]'s newline normalization (if any). *)
 
-val pp_decode : Format.formatter -> 
+val pp_decode : Format.formatter ->
   [< `Await | `Uchar of uchar | `End | `Malformed of string] -> unit
 (** [pp_decode ppf v] prints an unspecified representation of [v] on
     [ppf]. *)
@@ -282,7 +287,7 @@ type encoder
 
 val encoder : [< encoding] -> [< dst] -> encoder
 (** [encoder encoding dst] is an encoder for [encoding] that outputs
-    to [dst]. 
+    to [dst].
 
     {b Note.} No initial
     {{:http://unicode.org/glossary/#byte_order_mark}BOM}
@@ -303,13 +308,13 @@ val encode : encoder -> [<`Await | `End | `Uchar of uchar ] -> [`Ok | `Partial ]
     was written).
 
     {b Warning.} The function assumes that [u] is a Unicode
-    {{:http://unicode.org/glossary/#unicode_scalar_value}scalar value}. 
-    If you are handling foreign data you can use {!is_uchar} to assert that. 
+    {{:http://unicode.org/glossary/#unicode_scalar_value}scalar value}.
+    If you are handling foreign data you can use {!is_uchar} to assert that.
 
     {b Raises.} [Invalid_argument] if an [`Uchar] or [`End] is encoded
     after a [`Partial] encode. *)
 
-val encoder_encoding : encoder -> encoding 
+val encoder_encoding : encoder -> encoding
 (** [encoder_encoding e] is [e]'s encoding. *)
 
 val encoder_dst : encoder -> dst
@@ -317,13 +322,13 @@ val encoder_dst : encoder -> dst
 
 (** {1:manual Manual sources and destinations.} *)
 
-(** Manual sources and destinations. 
+(** Manual sources and destinations.
 
     {b Warning.} Use only with [`Manual] decoder and encoders. *)
 module Manual : sig
   val src : decoder -> string -> int -> int -> unit
-  (** [src d s j l] provides [d] with [l] bytes to read, starting at 
-      [j] in [s]. This byte range is read by calls to {!decode} with [d] 
+  (** [src d s j l] provides [d] with [l] bytes to read, starting at
+      [j] in [s]. This byte range is read by calls to {!decode} with [d]
       until [`Await] is returned. To signal the end of input call the function
       with [l = 0]. *)
 
@@ -333,7 +338,7 @@ module Manual : sig
       until [`Partial] is returned. Use {!dst_rem} to know the remaining
       number of non-written free bytes in [s]. *)
 
-  val dst_rem : encoder -> int 
+  val dst_rem : encoder -> int
   (** [dst_rem e] is the remaining number of non-written, free bytes
       in the last buffer provided with {!Manual.dst}. *)
 end
@@ -346,52 +351,52 @@ module String : sig
 (** {1 Encoding guess} *)
 
   val encoding_guess : string -> [ `UTF_8 | `UTF_16BE | `UTF_16LE ] * bool
-  (** [encoding_guess s] is the encoding guessed for [s] coupled with 
-      [true] iff there's an initial 
+  (** [encoding_guess s] is the encoding guessed for [s] coupled with
+      [true] iff there's an initial
       {{:http://unicode.org/glossary/#byte_order_mark}BOM}. *)
 
-(** {1 String folders} 
+(** {1 String folders}
 
-    {b Note.} Initial {{:http://unicode.org/glossary/#byte_order_mark}BOM}s 
-    are also folded over. *) 
+    {b Note.} Initial {{:http://unicode.org/glossary/#byte_order_mark}BOM}s
+    are also folded over. *)
 
-  type 'a folder = 'a -> int -> [ `Uchar of uchar | `Malformed of string ] -> 
-    'a 
-  (** The type for character folders. The integer is the index in the 
+  type 'a folder = 'a -> int -> [ `Uchar of uchar | `Malformed of string ] ->
+    'a
+  (** The type for character folders. The integer is the index in the
       string where the [`Uchar] or [`Malformed] starts. *)
 
-  val fold_utf_8 : 'a folder -> 'a -> string -> 'a 
-  (** [fold_utf_8 f a s] is 
-      [f (] ... [(f (f a 0 u]{_0}[) j]{_1}[ u]{_1}[)] ... [)] ... [) 
+  val fold_utf_8 : 'a folder -> 'a -> string -> 'a
+  (** [fold_utf_8 f a s] is
+      [f (] ... [(f (f a 0 u]{_0}[) j]{_1}[ u]{_1}[)] ... [)] ... [)
       j]{_n}[ u]{_n}
       where [u]{_i}, [j]{_i} are the Unicode
-      {{:http://unicode.org/glossary/#unicode_scalar_value} scalar value} 
-      and the starting position of the characters in the 
+      {{:http://unicode.org/glossary/#unicode_scalar_value} scalar value}
+      and the starting position of the characters in the
       UTF-8 encoded string [s]. *)
 
   val fold_utf_16be : 'a folder -> 'a -> string -> 'a
-  (** [fold_utf_16be f a s] is 
+  (** [fold_utf_16be f a s] is
       [f (] ... [(f (f a 0 u]{_0}[) j]{_1}[ u]{_1}[)] ... [)] ... [)
       j]{_n}[ u]{_n}
       where [u]{_i}, [j]{_i} are the Unicode
-      {{:http://unicode.org/glossary/#unicode_scalar_value}scalar value} 
-      and the starting position of the characters in the 
+      {{:http://unicode.org/glossary/#unicode_scalar_value}scalar value}
+      and the starting position of the characters in the
       UTF-16BE encoded string [s]. *)
 
   val fold_utf_16le : 'a folder -> 'a -> string -> 'a
-  (** [fold_utf_16le f a s] is 
+  (** [fold_utf_16le f a s] is
       [f (] ... [(f (f a 0 u]{_0}[) j]{_1}[ u]{_1}[)] ... [)] ... [)
       j]{_n}[ u]{_n}
       where [u]{_i}, [j]{_i} are the Unicode
-      {{:http://unicode.org/glossary/#unicode_scalar_value}scalar value} 
-      and the starting position of the characters in the 
+      {{:http://unicode.org/glossary/#unicode_scalar_value}scalar value}
+      and the starting position of the characters in the
       UTF-16LE encoded string [s]. *)
 end
 
 (**  UTF encode characters in OCaml {!Buffer.t} values. *)
-module Buffer : sig 
+module Buffer : sig
 
-  (** {1 Buffer encoders} 
+  (** {1 Buffer encoders}
 
       {b Warning.} All the functions below assumes that [u] is a
       {{:http://unicode.org/glossary/#unicode_scalar_value} unicode
@@ -414,7 +419,7 @@ module Buffer : sig
       scalar value} [u] to [b]. *)
 end
 
-(** {1:examples Examples} 
+(** {1:examples Examples}
 
     {2:readlines Read lines}
 
@@ -424,33 +429,33 @@ end
     Unicode 6.1.0. If a decoding error occurs we silently replace the
     malformed sequence by the replacement character {!u_rep} and continue.
 {[let lines ?encoding (src : [`Channel of in_channel | `String of string]) =
-  let rec loop d buf acc = match Uutf.decode d with 
-  | `Uchar 0x000A -> 
+  let rec loop d buf acc = match Uutf.decode d with
+  | `Uchar 0x000A ->
       let line = Buffer.contents buf in
       Buffer.clear buf; loop d buf (line :: acc)
   | `Uchar u -> Uutf.Buffer.add_utf_8 buf u; loop d buf acc
-  | `End -> List.rev (Buffer.contents buf :: acc)  
+  | `End -> List.rev (Buffer.contents buf :: acc)
   | `Malformed _ -> Uutf.Buffer.add_utf_8 buf Uutf.u_rep; loop d buf acc
   | `Await -> assert false
   in
   let nln = `Readline 0x000A in
   loop (Uutf.decoder ~nln ?encoding src) (Buffer.create 512) []]}
-  
-  Using the [`Manual] interface, [lines_fd] does the same but on a Unix file 
-  descriptor. 
+
+  Using the [`Manual] interface, [lines_fd] does the same but on a Unix file
+  descriptor.
 {[let lines_fd ?encoding (fd : Unix.file_descr) =
-  let rec loop fd s d buf acc = match Uutf.decode d with 
-  | `Uchar 0x000A -> 
+  let rec loop fd s d buf acc = match Uutf.decode d with
+  | `Uchar 0x000A ->
       let line = Buffer.contents buf in
       Buffer.clear buf; loop fd s d buf (line :: acc)
   | `Uchar u -> Uutf.Buffer.add_utf_8 buf u; loop fd s d buf acc
   | `End -> List.rev (Buffer.contents buf :: acc)
   | `Malformed _ -> Uutf.Buffer.add_utf_8 buf Uutf.u_rep; loop fd s d buf acc
   | `Await ->
-      let rec unix_read fd s j l = try Unix.read fd s j l with 
-      | Unix.Unix_error (Unix.EINTR, _, _) -> unix_read fd s j l 
+      let rec unix_read fd s j l = try Unix.read fd s j l with
+      | Unix.Unix_error (Unix.EINTR, _, _) -> unix_read fd s j l
       in
-      let rc = unix_read fd s 0 (String.length s) in 
+      let rc = unix_read fd s 0 (String.length s) in
       Uutf.Manual.src d s 0 rc; loop fd s d buf acc
   in
   let s = String.create 65536 (* UNIX_BUFFER_SIZE in 4.0.0 *) in
@@ -465,60 +470,60 @@ end
     decoding error occurs we silently replace the malformed sequence
     by the replacement character {!u_rep} and continue.  Note that we
     don't add an initial
-    {{:http://unicode.org/glossary/#byte_order_mark}BOM} to [dst], 
+    {{:http://unicode.org/glossary/#byte_order_mark}BOM} to [dst],
     recoding will thus loose the initial BOM [src] may have. Whether
     this is a problem or not depends on the context.
-{[let recode ?nln ?encoding out_encoding 
+{[let recode ?nln ?encoding out_encoding
     (src : [`Channel of in_channel | `String of string])
     (dst : [`Channel of out_channel | `Buffer of Buffer.t])
-  = 
-  let rec loop d e = match Uutf.decode d with 
-  | `Uchar _ as u -> ignore (Uutf.encode e u); loop d e 
+  =
+  let rec loop d e = match Uutf.decode d with
+  | `Uchar _ as u -> ignore (Uutf.encode e u); loop d e
   | `End -> ignore (Uutf.encode e `End)
-  | `Malformed _ -> ignore (Uutf.encode e (`Uchar Uutf.u_rep)); loop d e 
+  | `Malformed _ -> ignore (Uutf.encode e (`Uchar Uutf.u_rep)); loop d e
   | `Await -> assert false
   in
-  let d = Uutf.decoder ?nln ?encoding src in 
+  let d = Uutf.decoder ?nln ?encoding src in
   let e = Uutf.encoder out_encoding dst in
   loop d e]}
   Using the [`Manual] interface, [recode_fd] does the same but between
   Unix file descriptors.
-{[let recode_fd ?nln ?encoding out_encoding 
-    (fdi : Unix.file_descr) 
-    (fdo : Unix.file_descr) 
-  = 
-  let rec encode fd s e v = match Uutf.encode e v with `Ok -> () 
-  | `Partial -> 
-      let rec unix_write fd s j l = 
-        let rec write fd s j l = try Unix.single_write fd s j l with 
-        | Unix.Unix_error (Unix.EINTR, _, _) -> write fd s j l 
+{[let recode_fd ?nln ?encoding out_encoding
+    (fdi : Unix.file_descr)
+    (fdo : Unix.file_descr)
+  =
+  let rec encode fd s e v = match Uutf.encode e v with `Ok -> ()
+  | `Partial ->
+      let rec unix_write fd s j l =
+        let rec write fd s j l = try Unix.single_write fd s j l with
+        | Unix.Unix_error (Unix.EINTR, _, _) -> write fd s j l
         in
-        let wc = write fd s j l in 
+        let wc = write fd s j l in
         if wc < l then unix_write fd s (j + wc) (l - wc) else ()
       in
-      unix_write fd s 0 (String.length s - Uutf.Manual.dst_rem e); 
+      unix_write fd s 0 (String.length s - Uutf.Manual.dst_rem e);
       Uutf.Manual.dst e s 0 (String.length s);
       encode fd s e `Await
   in
-  let rec loop fdi fdo ds es d e = match Uutf.decode d with 
-  | `Uchar _ as u -> encode fdo es e u; loop fdi fdo ds es d e 
+  let rec loop fdi fdo ds es d e = match Uutf.decode d with
+  | `Uchar _ as u -> encode fdo es e u; loop fdi fdo ds es d e
   | `End -> encode fdo es e `End
-  | `Malformed _ -> encode fdo es e (`Uchar Uutf.u_rep); loop fdi fdo ds es d e 
+  | `Malformed _ -> encode fdo es e (`Uchar Uutf.u_rep); loop fdi fdo ds es d e
   | `Await ->
-      let rec unix_read fd s j l = try Unix.read fd s j l with 
-      | Unix.Unix_error (Unix.EINTR, _, _) -> unix_read fd s j l 
+      let rec unix_read fd s j l = try Unix.read fd s j l with
+      | Unix.Unix_error (Unix.EINTR, _, _) -> unix_read fd s j l
       in
-      let rc = unix_read fdi ds 0 (String.length ds) in 
-      Uutf.Manual.src d ds 0 rc; loop fdi fdo ds es d e 
+      let rc = unix_read fdi ds 0 (String.length ds) in
+      Uutf.Manual.src d ds 0 rc; loop fdi fdo ds es d e
   in
   let ds = String.create 65536 (* UNIX_BUFFER_SIZE in 4.0.0 *) in
   let es = String.create 65536 (* UNIX_BUFFER_SIZE in 4.0.0 *) in
-  let d = Uutf.decoder ?nln ?encoding `Manual in 
+  let d = Uutf.decoder ?nln ?encoding `Manual in
   let e = Uutf.encoder out_encoding `Manual in
   Uutf.Manual.dst e es 0 (String.length es);
   loop fdi fdo ds es d e]}
 *)
-    
+
 (*---------------------------------------------------------------------------
    Copyright 2012 Daniel C. Bünzli
    All rights reserved.
@@ -526,7 +531,7 @@ end
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions
    are met:
-     
+
    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.
 
